unit AddictRaveWizard;

interface

uses
     Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
     StdCtrls, Buttons, ExtCtrls, RvClass, RvProj, RvTool, RvToolEvents,
     ComCtrls, ad3RichEdit, ad3ThesaurusBase, ad3Thesaurus, ad3SpellBase,
     ad3Spell, ToolWin;

type
     TFormAddictWizard = class (TForm)
          TextComponents: TListBox;
          ComponentText: TAddictRichEdit;
          TextComponentsLbl: TLabel;
          ComponentTextLbl: TLabel;
          AddictSpell31: TAddictSpell3;
          Thesaurus31: TThesaurus3;
          ToolBar1: TToolBar;
          OptionsBtn: TToolButton;
          ToolButton2: TToolButton;
          ThesaurusBtn: TToolButton;
          ToolButton4: TToolButton;
          AboutBtn: TToolButton;
          AdLbl2: TLabel;
          AdLbl1: TLabel;
          SpellAllBtn: TSpeedButton;
          SpellBtn: TToolButton;
          ToolButton3: TToolButton;
          procedure FormCreate (Sender: TObject);
          procedure FormDestroy (Sender: TObject);
          procedure FormShow (Sender: TObject);
          procedure TextComponentsClick (Sender: TObject);
          procedure ComponentTextChange (Sender: TObject);
          procedure FormResize (Sender: TObject);
          procedure OptionsBtnClick (Sender: TObject);
          procedure ThesaurusBtnClick (Sender: TObject);
          procedure AboutBtnClick (Sender: TObject);
          procedure AdLbl2Click (Sender: TObject);
          procedure SpellAllBtnClick (Sender: TObject);
          procedure SpellBtnClick (Sender: TObject);
     private
          { Private declarations }
     public
          { Public declarations }
     end;

     TAddictWizardProjectEditor = class (TRaveMasterProjectEditor, IRaveToolMenuEventHandler)
     protected
     public
          constructor Create; override;
          destructor Destroy; override;
          procedure Initialize; override;
          procedure AddToMenu (AddMenuItem: TAddMenuItemProc);
          procedure RunFromMenu (ID: integer);
     end; { TAddictWizardProjectEditor }

var
     FormAddictWizard: TFormAddictWizard;

procedure RaveRegister;

implementation

{$R *.DFM}

uses
     RvToolUtil, About;

procedure RaveRegister;
begin { RaveRegister }
     RegisterRaveProjectEditor (TAddictWizardProjectEditor);
end; { RaveRegister }

{ TFormReportExpert }

procedure TFormAddictWizard.FormCreate (Sender: TObject);
begin
     PrepareToolWin (self);
end;

procedure TFormAddictWizard.FormDestroy (Sender: TObject);
begin
     SaveToolWin (self);
end;

procedure TFormAddictWizard.FormShow (Sender: TObject);
begin
     RestoreToolWin (self);
end;

procedure TFormAddictWizard.TextComponentsClick (Sender: TObject);
begin
     ComponentText.Text := TRaveControl (TextComponents.Items.Objects [TextComponents.ItemIndex]).Text;
     ComponentTextLbl.Caption := 'Component Text for ' + TextComponents.Items [TextComponents.ItemIndex];
end;

procedure TFormAddictWizard.ComponentTextChange (Sender: TObject);
begin
     TRaveControl (TextComponents.Items.Objects [TextComponents.ItemIndex]).Text := ComponentText.Text;
     ProjectManager.DataChanged := true; // Mark project as changed
end;

{ TAddictWizardProjectEditor }

constructor TAddictWizardProjectEditor.Create;
begin { Create }
     inherited Create;
end; { Create }

destructor TAddictWizardProjectEditor.Destroy;
begin { Destroy }
     inherited Destroy;
end; { Destroy }

procedure TAddictWizardProjectEditor.AddToMenu (AddMenuItem: TAddMenuItemProc);
begin { AddToMenu }
     AddMenuItem (Self, 'SpellCheck with Addict', 1, 0);
end; { AddToMenu }

procedure TAddictWizardProjectEditor.RunFromMenu (ID: integer);
var
     I1: integer;
     I2: integer;
begin { RunFromMenu }
     { Display form and do your stuff }
     with TFormAddictWizard.Create (Application) do
     try
          // Initialize form with text components
          with ProjectManager.ActiveReport do
          begin
               for I1 := 0 to LoadedPageCount - 1 do
               begin
                    with LoadedPage [I1] do
                    begin
                         for I2 := 0 to ComponentCount - 1 do
                         begin
                              if (Components [I2] is TRaveControl) and (TRaveControl (Components [I2]).Text <> '') then
                              begin
                                   TextComponents.Items.AddObject (Components [I2].Name, Components [I2]);
                              end; { if }
                         end; { for }
                    end; { with }
               end; { for }
          end; { with }

          // Show the form
          ShowModal;
     finally
          Free;
     end; { with }
end; { RunFromMenu }

procedure TAddictWizardProjectEditor.Initialize;
var
     ShortCutList: TStringList;
begin { Initialize }
     with RaveSettings.LockSection ('ShortCuts') do
     try
          ShortCutList := TStringList.Create;
          try
               ReadSectionValues ('ShortCuts', ShortCutList);
               if ShortCutList.Values ['TAddictWizardProjectEditor@SpellCheck with Addict'] = '' then
               begin
                    WriteInteger ('TAddictWizardProjectEditor@SpellCheck with Addict', 118); // F7
               end; { if }
          finally
               FreeAndNil (ShortCutList);
          end; { tryf }
     finally
          UnlockSection;
     end; { with }
end; { Initialize }

procedure TFormAddictWizard.FormResize (Sender: TObject);
const
     Gap = 5;
var
     X: Integer;
begin
     TextComponents.Left := Gap;
     X := (ClientWidth - 3 * Gap) div 2;
     TextComponents.Width := X;
     ComponentText.Width := X;
     ComponentText.Left := X + 2 * Gap;
     ComponentTextLbl.Left := ComponentText.Left;

     X := (ClientHeight - (TextComponents.Top + AdLbl1.Height + AdLbl2.Height
          + 3 * Gap));
     ComponentText.Height := X;
     TextComponents.Height := X;

     AdLbl1.Left := Gap;
     AdLbl1.Top := TextComponents.Top + TextComponents.Height + Gap;
     AdLbl2.Left := Gap;
     AdLbl2.Top := AdLbl1.Top + AdLbl1.Height + Gap;
end;

procedure TFormAddictWizard.OptionsBtnClick (Sender: TObject);
begin
     AddictSpell31.Setup;
end;

procedure TFormAddictWizard.ThesaurusBtnClick (Sender: TObject);
begin
     Thesaurus31.LookupWinControl (ComponentText)
end;

procedure TFormAddictWizard.AboutBtnClick (Sender: TObject);
begin
     ShowAbout;
end;

procedure TFormAddictWizard.AdLbl2Click (Sender: TObject);
begin
     ExecuteFile ('http://www.addictivesoftware.com');
end;

procedure TFormAddictWizard.SpellAllBtnClick (Sender: TObject);
var
     I: Integer;
begin
     if TextComponents.Count > 0 then
     begin
          ComponentText.HideSelection := False;
          try
               AddictSpell31.StartSequenceCheck;
               for I := 0 to TextComponents.Count - 1 do
               begin
                    TextComponents.ItemIndex := I;
                    TextComponentsClick (Sender);
                    AddictSpell31.CheckWinControl (ComponentText, ctAll);
               end;
               AddictSpell31.StopSequenceCheck;
          finally
               ComponentText.HideSelection := True;
          end;
     end;
end;

procedure TFormAddictWizard.SpellBtnClick (Sender: TObject);
begin
     ComponentText.HideSelection := False;
     try
          AddictSpell31.CheckWinControl (ComponentText, ctAll);
     finally
          ComponentText.HideSelection := True;
     end;
end;

initialization
     RegisterProc ('Addict', RaveRegister);
end.

